===========
 Changelog
===========

2.5 (2017-02-04)
================

- Update test infrastructure to `icemac.addressbook >= 3.0`.


2.4 (2017-01-21)
================

- Update code to support `icemac.addressbook >= 2.9`.


2.3 (2017-01-07)
================

- Bring branch test coverage to 100 %.

- Adapt configuration of user roles and code to `icemac.addressbook >= 2.9`.


Previous versions
=================

See ``OLD_CHANGES.rst`` inside the package.
